import sys
import os
import logging
from logging.handlers import RotatingFileHandler
from datetime import datetime

# Add the application root to the Python path
sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))

from models.base import Session
from models.message import Message
from config import IMAGE_SAVE_PATH, VIDEOS_SAVE_PATH

# Configure logging
logger = logging.getLogger(__name__)

def setup_logging():
    os.makedirs('logs', exist_ok=True)
    formatter = logging.Formatter('%(asctime)s - %(levelname)s - %(message)s')
    
    file_handler = RotatingFileHandler(
        'logs/cleanup.log', 
        maxBytes=10000000,
        backupCount=5
    )
    file_handler.setFormatter(formatter)
    logger.addHandler(file_handler)
    logger.setLevel(logging.INFO)

def delete_media_file(local_url):
    if not local_url:
        return

    try:
        if os.path.exists(local_url):
            os.remove(local_url)
            logger.info(f"Deleted media file: {local_url}")
        else:
            logger.warning(f"Media file not found: {local_url}")
    except Exception as e:
        logger.error(f"Error deleting media file {local_url}: {str(e)}")

def cleanup_messages():
    session = Session()
    try:
        # Get the last 100 messages ordered by timestamp
        messages = session.query(Message)\
            .order_by(Message.timestamp.desc())\
            .limit(100)\
            .all()

        if not messages:
            logger.info("No messages found to delete")
            return 0

        count = 0
        for message in messages:
            # Delete associated media files if they exist
            if message.message_type in ['image', 'video'] and message.local_url:
                delete_media_file(message.local_url)
            
            # Delete the message from database
            session.delete(message)
            count += 1

        session.commit()
        logger.info(f"Successfully deleted {count} messages and their associated media files")
        return count

    except Exception as e:
        logger.error(f"Error during cleanup: {str(e)}", exc_info=True)
        session.rollback()
        return 0
    finally:
        session.close()

if __name__ == "__main__":
    setup_logging()
    cleanup_messages()
